Defines common arguments shared across multiple functions in the package
to avoid repetition by using inheritParams.
Object of class teal_module to be used in teal applications.
(numeric) optional, specifies the plot height as a three-element vector of
value, min, and max intended for use with a slider UI element.
(numeric) optional, specifies the plot width as a three-element vector of
value, min, and max for a slider encoding the plot width.
(logical) optional, whether to rotate plot X axis labels. Does not
rotate by default (FALSE).
(character) optional, ggplot2 theme to be used by default. Defaults to "gray".
(ggplot2_args) object created by teal.widgets::ggplot2_args()
with settings for the module plot.
The argument is merged with options variable teal.ggplot2_args and default module setup.
For more details see the vignette: vignette("custom-ggplot2-arguments", package = "teal.widgets")
(basic_table_args) object created by teal.widgets::basic_table_args()
with settings for the module table.
The argument is merged with options variable teal.basic_table_args and default module setup.
For more details see the vignette: vignette("custom-basic-table-arguments", package = "teal.widgets")
(shiny.tag) optional, text or UI element to be displayed before the module's output,
providing context or a title.
with text placed before the output to put the output into context. For example a title.
(shiny.tag) optional, text or UI element to be displayed after the module's output,
adding context or further instructions. Elements like shiny::helpText() are useful.
(integer(1) or integer(3)) optional, specifies point opacity.
When the length of alpha is one: the plot points will have a fixed opacity.
When the length of alpha is three: the plot points opacity are dynamically adjusted based on
vector of value, min, and max.
(integer(1) or integer(3)) optional, specifies point size.
When the length of size is one: the plot point sizes will have a fixed size.
When the length of size is three: the plot points size are dynamically adjusted based on
vector of value, min, and max.
(named
list of lists of teal_transform_module) optional,
decorator for tables or plots included in the module output reported.
The decorators are applied to the respective output objects.
(character) names of the datasets which should be listed below the plot
when some data points are selected. Objects named after table_datanames will be pulled from
data so it is important that data actually contains these datasets. Please be aware that
table datasets must be linked with plot_dataname by the relevant join_keys().
See section "Decorating Module" below for more details.