View source: R/tm_g_bivariate.R
| tm_g_bivariate | R Documentation |
teal module: Univariate and bivariate visualizationsModule enables the creation of univariate and bivariate plots, facilitating the exploration of data distributions and relationships between two variables.
tm_g_bivariate(
label = "Bivariate Plots",
x = teal.picks::picks(teal.picks::datasets(), teal.picks::variables(choices =
is.numeric | teal.picks::is_categorical(min.len = 2, max.len = 10), selected = 1L),
teal.picks::values()),
y,
row_facet,
col_facet,
facet,
color = NULL,
fill = NULL,
size = NULL,
use_density = FALSE,
color_settings = FALSE,
free_x_scales = FALSE,
free_y_scales = FALSE,
plot_height = c(600, 200, 2000),
plot_width = NULL,
rotate_xaxis_labels = FALSE,
swap_axes = FALSE,
ggtheme = c("gray", "bw", "linedraw", "light", "dark", "minimal", "classic", "void"),
ggplot2_args = teal.widgets::ggplot2_args(),
pre_output = NULL,
post_output = NULL,
transformators = list(),
decorators = list()
)
This is a general module to visualize 1 & 2 dimensional data.
Object of class teal_module to be used in teal applications.
This module generates the following objects, which can be modified in place using decorators:
plot (ggplot)
A Decorator is applied to the specific output using a named list of teal_transform_module objects.
The name of this list corresponds to the name of the output to which the decorator is applied.
See code snippet below:
tm_g_bivariate(
..., # arguments for module
decorators = list(
plot = teal_transform_module(...) # applied to the `plot` output
)
)
For additional details and examples of decorators, refer to the vignette
vignette("decorate-module-output", package = "teal.modules.general").
To learn more please refer to the vignette
vignette("transform-module-output", package = "teal") or the teal::teal_transform_module() documentation.
This module returns an object of class teal_module, that contains a server function.
Since the server function returns a teal_report object, this makes this module reportable, which means that
the reporting functionality will be turned on automatically by the teal framework.
For more information on reporting in teal, see the vignettes:
vignette("reportable-shiny-application", package = "teal.reporter")
vignette("adding-support-for-reporting-to-custom-modules", package = "teal")
For more examples, please see the vignette "Using bivariate plot" via
vignette("using-bivariate-plot", package = "teal.modules.general").
# general data example
data <- teal_data()
data <- within(data, {
require(nestcolor)
CO2 <- data.frame(CO2)
})
app <- init(
data = data,
modules = tm_g_bivariate(
label = "Bivariate Plots",
x = teal.picks::picks(
datasets("CO2"),
teal.picks::variables(selected = "conc")
),
y = teal.picks::picks(
datasets("CO2"),
teal.picks::variables(selected = "uptake")
),
row_facet = teal.picks::picks(
datasets("CO2"),
teal.picks::variables(selected = "Type")
),
col_facet = teal.picks::picks(
datasets("CO2"),
teal.picks::variables(selected = "Treatment")
)
)
)
if (interactive()) {
shinyApp(app$ui, app$server)
}
# CDISC data example
data <- teal_data()
data <- within(data, {
require(nestcolor)
ADSL <- teal.data::rADSL
})
join_keys(data) <- default_cdisc_join_keys[names(data)]
app <- init(
data = data,
modules = tm_g_bivariate(
label = "Bivariate Plots",
x = teal.picks::picks(
datasets("ADSL"),
teal.picks::variables(selected = "AGE")
),
y = teal.picks::picks(
datasets("ADSL"),
teal.picks::variables(selected = "SEX")
),
row_facet = teal.picks::picks(
datasets("ADSL"),
teal.picks::variables(selected = "ARM")
),
col_facet = teal.picks::picks(
datasets("ADSL"),
teal.picks::variables(selected = "COUNTRY")
)
)
)
if (interactive()) {
shinyApp(app$ui, app$server)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.