- label
(character(1)) Label shown in the navigation item for the module or module group.
For modules() defaults to "root". See Details.
- regressor
(picks) Specification for regressor variables selection.
Created using teal.picks::picks(), which allows selecting variables
to use as regressors in the regression model. teal.picks::variables(multiple = TRUE) allowed.
- response
(picks) Specification for response variable selection.
Created using teal.picks::picks(), which allows selecting a single numeric variable
to use as the response in the regression model. teal.picks::variables(multiple = TRUE) not allowed.
- outlier
(picks) Optional specification for outlier label variable selection.
Created using teal.picks::picks(), which allows selecting a factor or character variable
to label outlier points on the plots.
- plot_height
(numeric) optional, specifies the plot height as a three-element vector of
value, min, and max intended for use with a slider UI element.
- plot_width
(numeric) optional, specifies the plot width as a three-element vector of
value, min, and max for a slider encoding the plot width.
- alpha
(integer(1) or integer(3)) optional, specifies point opacity.
When the length of alpha is one: the plot points will have a fixed opacity.
When the length of alpha is three: the plot points opacity are dynamically adjusted based on
vector of value, min, and max.
- size
(integer(1) or integer(3)) optional, specifies point size.
When the length of size is one: the plot point sizes will have a fixed size.
When the length of size is three: the plot points size are dynamically adjusted based on
vector of value, min, and max.
- ggtheme
(character) optional, ggplot2 theme to be used by default. Defaults to "gray".
- ggplot2_args
(ggplot2_args) optional, object created by teal.widgets::ggplot2_args() with settings for all the plots or named list of ggplot2_args objects for plot-specific settings. The argument is merged with options variable teal.ggplot2_args and default module setup.
List names should match the following: c("default", "Response vs Regressor", "Residuals vs Fitted", "Scale-Location", "Cook's distance", "Residuals vs Leverage", "Cook's dist vs Leverage").
For more details see the vignette: vignette("custom-ggplot2-arguments", package = "teal.widgets").
- pre_output
(shiny.tag) optional, text or UI element to be displayed before the module's output,
providing context or a title.
with text placed before the output to put the output into context. For example a title.
- post_output
(shiny.tag) optional, text or UI element to be displayed after the module's output,
adding context or further instructions. Elements like shiny::helpText() are useful.
- default_plot_type
(numeric) optional, defaults to "Response vs Regressor".
Response vs Regressor
Residuals vs Fitted
Normal Q-Q
Scale-Location
Cook's distance
Residuals vs Leverage
Cook's dist vs Leverage
- default_outlier_label
(character) optional, default column selected to label outliers.
- label_segment_threshold
(numeric(1) or numeric(3))
Minimum distance between label and point on the plot that triggers the creation of
a line segment between the two.
This may happen when the label cannot be placed next to the point as it overlaps another
label or point.
The value is used as the min.segment.length parameter to the ggrepel::geom_text_repel() function.
It can take the following forms:
numeric(1): Fixed value used for the minimum distance and the slider is not presented in the UI.
numeric(3): A slider is presented in the UI (under "Plot settings") to adjust the minimum distance dynamically.
It takes the form of c(value, min, max) and it is passed to the value_min_max
argument in teal.widgets::optionalSliderInputValMinMax.
- transformators
(list of teal_transform_module) that will be applied to transform module's data input.
To learn more check vignette("transform-input-data", package = "teal").
- decorators
(named list of lists of teal_transform_module) optional,
decorator for tables or plots included in the module output reported.
The decorators are applied to the respective output objects.