- label
(character(1)) Label shown in the navigation item for the module or module group.
For modules() defaults to "root". See Details.
- x
(picks) Variable specification for the x-axis. Created using teal.picks::picks().
Can be numeric, factor or character. No empty selections are allowed.
- y
(picks) Variable specification for the y-axis. Created using teal.picks::picks().
Can be numeric, factor or character.
- row_facet
(picks) optional, specification of the data variable(s) to use for faceting rows.
Created using teal.picks::picks().
- col_facet
(picks) optional, specification of the data variable(s) to use for faceting columns.
Created using teal.picks::picks().
- facet
(logical) optional, specifies whether the facet encodings ui elements are toggled
on and shown to the user by default. Defaults to TRUE if either row_facet or column_facet
are supplied.
- color
(picks) optional, specification of the data variable(s) selected for the outline color
inside the coloring settings. It will be applied when color_settings is set to TRUE.
Created using teal.picks::picks().
- fill
(picks) optional, specification of the data variable(s) selected for the fill color
inside the coloring settings. It will be applied when color_settings is set to TRUE.
Created using teal.picks::picks().
- size
(picks) optional, specification of the data variable(s) selected for the size of
geom_point plots inside the coloring settings. It will be applied when color_settings is set to TRUE.
Created using teal.picks::picks().
- use_density
(logical) optional, indicates whether to plot density (TRUE) or frequency (FALSE).
Defaults to frequency (FALSE).
- color_settings
(logical) Whether coloring, filling and size should be applied
and UI tool offered to the user.
- free_x_scales
(logical) optional, whether X scaling shall be changeable.
Does not allow scaling to be changed by default (FALSE).
- free_y_scales
(logical) optional, whether Y scaling shall be changeable.
Does not allow scaling to be changed by default (FALSE).
- plot_height
(numeric) optional, specifies the plot height as a three-element vector of
value, min, and max intended for use with a slider UI element.
- plot_width
(numeric) optional, specifies the plot width as a three-element vector of
value, min, and max for a slider encoding the plot width.
- rotate_xaxis_labels
(logical) optional, whether to rotate plot X axis labels. Does not
rotate by default (FALSE).
- swap_axes
(logical) optional, whether to swap X and Y axes. Defaults to FALSE.
- ggtheme
(character) optional, ggplot2 theme to be used by default. Defaults to "gray".
- ggplot2_args
(ggplot2_args) object created by teal.widgets::ggplot2_args()
with settings for the module plot.
The argument is merged with options variable teal.ggplot2_args and default module setup.
For more details see the vignette: vignette("custom-ggplot2-arguments", package = "teal.widgets")
- pre_output
(shiny.tag) optional, text or UI element to be displayed before the module's output,
providing context or a title.
with text placed before the output to put the output into context. For example a title.
- post_output
(shiny.tag) optional, text or UI element to be displayed after the module's output,
adding context or further instructions. Elements like shiny::helpText() are useful.
- transformators
(list of teal_transform_module) that will be applied to transform module's data input.
To learn more check vignette("transform-input-data", package = "teal").
- decorators
(named list of lists of teal_transform_module) optional,
decorator for tables or plots included in the module output reported.
The decorators are applied to the respective output objects.